pub struct Responses {
pub default: Option<Referenceable<Response>>,
pub data: BTreeMap<String, Referenceable<Response>>,
}Expand description
A container for the expected responses of an operation.
Fields
default: Option<Referenceable<Response>>The documentation of responses other than the ones declared for specific HTTP response codes.
data: BTreeMap<String, Referenceable<Response>>Implementations
Sourceimpl Responses
impl Responses
pub fn new() -> Self
pub fn with_status( self, status: impl Into<String>, response: Referenceable<Response>, ) -> Self
pub fn with_default(self, response: Referenceable<Response>) -> Self